%%
%% This is file `cp862.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hebinp.dtx  (with options: `cp862')
%% 
%% This is a generated file.
%% 
%% Hebrew language font and input encodings, and additional packages.
%% Copyright (C) 1997 -- 2005 Boris Lavva and Johannes Braams.
%% 
%% Copyright (C) 2023 Udi Fogiel.
%% All rights reserved.
%% 
%% It may be distributed and/or modified under the conditions of the
%% LaTeX Project Public License, either version 1.3 of this license or
%% (at your option) any later version. The latest version of this
%% license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX version
%% 2003/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainer of this work is Udi Fogiel
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.
  \ProvidesFile{cp862.def}
        [2023/08/21 v1.3 Hebrew input encoding file]
\makeatletter
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textflorin}{\textit{f}}
\ProvideTextCommandDefault{\textpeseta}{Pt}
\ProvideTextCommandDefault{\textblacksquare}
   {\vrule \@width .3em \@height .4em \@depth -.1em\relax}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\providecommand{\mathtwosuperior}{{^2}}
\providecommand{\mathordmasculine}{{^o}}
\providecommand{\mathordfeminine}{{^a}}
\DeclareInputText{128}{\hebalef}
\DeclareInputText{129}{\hebbet}
\DeclareInputText{130}{\hebgimel}
\DeclareInputText{131}{\hebdalet}
\DeclareInputText{132}{\hebhe}
\DeclareInputText{133}{\hebvav}
\DeclareInputText{134}{\hebzayin}
\DeclareInputText{135}{\hebhet}
\DeclareInputText{136}{\hebtet}
\DeclareInputText{137}{\hebyod}
\DeclareInputText{138}{\hebfinalkaf}
\DeclareInputText{139}{\hebkaf}
\DeclareInputText{140}{\heblamed}
\DeclareInputText{141}{\hebfinalmem}
\DeclareInputText{142}{\hebmem}
\DeclareInputText{143}{\hebfinalnun}
\DeclareInputText{144}{\hebnun}
\DeclareInputText{145}{\hebsamekh}
\DeclareInputText{146}{\hebayin}
\DeclareInputText{147}{\hebfinalpe}
\DeclareInputText{148}{\hebpe}
\DeclareInputText{149}{\hebfinaltsadi}
\DeclareInputText{150}{\hebtsadi}
\DeclareInputText{151}{\hebqof}
\DeclareInputText{152}{\hebresh}
\DeclareInputText{153}{\hebshin}
\DeclareInputText{154}{\hebtav}
\DeclareInputText{155}{\textcent}
\DeclareInputText{156}{\pounds}
\DeclareInputText{157}{\textyen}
\DeclareInputText{158}{\textpeseta}
\DeclareInputText{159}{\textflorin}
\DeclareInputText{160}{\@tabacckludge'a}
\DeclareInputText{161}{\@tabacckludge'\i}
\DeclareInputText{162}{\@tabacckludge'o}
\DeclareInputText{163}{\@tabacckludge'u}
\DeclareInputText{164}{\~n}
\DeclareInputText{165}{\~N}
\DeclareInputMath{166}{\mathordfeminine}
\DeclareInputMath{167}{\mathordmasculine}
\DeclareInputText{168}{\textquestiondown}
\DeclareInputMath{170}{\lnot}
\DeclareInputText{171}{\textonehalf}
\DeclareInputText{172}{\textonequarter}
\DeclareInputText{173}{\textexclamdown}
\DeclareInputText{174}{\guillemotleft}
\DeclareInputText{175}{\guillemotright}
\DeclareInputMath{224}{\alpha}
\DeclareInputText{225}{\ss}
\DeclareInputMath{226}{\Gamma}
\DeclareInputMath{227}{\pi}
\DeclareInputMath{228}{\Sigma}
\DeclareInputMath{229}{\sigma}
\DeclareInputMath{230}{\mu}
\DeclareInputMath{231}{\tau}
\DeclareInputMath{232}{\Phi}
\DeclareInputMath{233}{\Theta}
\DeclareInputMath{234}{\Omega}
\DeclareInputMath{235}{\delta}
\DeclareInputMath{236}{\infty}
\DeclareInputMath{237}{\phi}
\DeclareInputMath{238}{\varepsilon}
\DeclareInputMath{239}{\cap}
\DeclareInputMath{240}{\equiv}
\DeclareInputMath{241}{\pm}
\DeclareInputMath{242}{\ge}
\DeclareInputMath{243}{\le}
\DeclareInputMath{246}{\div}
\DeclareInputMath{247}{\approx}
\DeclareInputText{248}{\textdegree}
\DeclareInputText{249}{\textperiodcentered}
\DeclareInputText{250}{\textbullet}
\DeclareInputMath{251}{\surd}
\DeclareInputMath{252}{\mathnsuperior}
\DeclareInputMath{253}{\mathtwosuperior}
\DeclareInputText{254}{\textblacksquare}
\DeclareInputText{255}{\nobreakspace}
\makeatother
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
\endinput
%%
%% End of file `cp862.def'.
